abacusai.ai_building_task — AbacusAI documentation

# abacusai.ai_building_task

## Classes

`AiBuildingTask` | A task for Data Science Co-pilot to help build AI.

## Module Contents

class abacusai.ai_building_task.AiBuildingTask(client, task=None, taskType=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A task for Data Science Co-pilot to help build AI.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - task (str) – The task to be performed

    - taskType (str) – The type of task

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict